package cn.estsh.i3plus.pojo.aps.common;

import cn.estsh.i3plus.pojo.aps.annotation.ExcludeImportExport;
import cn.estsh.i3plus.pojo.aps.annotation.FieldAnnotation;
import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import com.fasterxml.jackson.annotation.JsonIgnore;
import io.swagger.annotations.ApiParam;
import lombok.Data;

import javax.persistence.Column;
import javax.persistence.Lob;
import javax.persistence.MappedSuperclass;
import javax.persistence.Transient;
import java.util.HashMap;

/**
 * @Description :APS基类
 * 对于APS所有实体类均需继承该类。
 * @Reference :
 * @Author : jason.niu
 * @CreateDate : 2019-09-17
 * @Modify:
 **/
@Data
@MappedSuperclass
@ExcludeImportExport
public abstract class BaseAPS extends BaseBean {
    private static final long serialVersionUID = -8638842158403944318L;

    @Lob
    @FieldAnnotation(property = false)
    private HashMap<String, Object> customFields = new HashMap<>();

    @ApiParam(value ="主键值")
    @FieldAnnotation(display = false)
    @Transient
    private String key;

    @FieldAnnotation(property = false)
    private transient Long updateId = 0L;

    public Object getCustomField(String code) {
        return customFields.get(code);
    }

    public void setCustomField(String code, Object value) {
        customFields.put(code, value);
    }

    public String getCustomString(String code) {
        Object value = customFields.get(code);
        if (value == null) {
            return "";
        }
        return value.toString();
    }

    public Integer getCustomInteger(String code) {
        Object value = customFields.get(code);
        if (value == null) {
            return null;
        }

        if (value.getClass() == String.class) {
            return Integer.valueOf((String) value);
        } else if(value.getClass() == Integer.class) {
            return (Integer)value;
        }
        return null;
    }

    public Double getCustomDouble(String code) {
        Object value = customFields.get(code);
        if (value == null) {
            return null;
        }

        if (value.getClass() == String.class) {
            return Double.valueOf((String) value);
        } else if(value.getClass() == Double.class) {
            return (Double)value;
        }
        return null;
    }

    public Boolean getCustomBoolean(String code) {
        Object value = customFields.get(code);
        if (value == null) {
            return null;
        }

        if (value.getClass() == Boolean.class) {
            return (Boolean) value;
        } else if(value.getClass() == Integer.class) {
            return (Integer)value == 1;
        }
        return null;
    }
}
